#### SECTION 1 ####

#1.1: Get all modules loaded
from ansys.dpf import post
from ansys.dpf import core as dpf
from ansys.dpf.core import operators as coreops
from ansys.dpf.core import fields_container_factory
from ansys.dpf.core.plotter import DpfPlotter
import pyvista as pv
import os

#1.2: Specify variables for filenames and directory
#     Make sure you change this to your directory and RST file
#     Note that Python converst / to \ on windows so you don't have to. 
rstFile = "twrtest1-str.rst"
rstDir = "C:/Users/eric.miller/OneDrive - PADT/Development/pyAnsys/twrtest/"
outroot= "twrtest1"

#1.3: Build the output file name
outfname = outroot + "-seqv-1.vtk"

#A.4: Let the user know what you have
print
("==========================================================================")
print ("Starting the translation of your Ansys results to a different file format")
print ("  Input file: ", rstFile)
print ("  Directory: ", rstDir)
print ("  Output file: ", outfname)
print 
("-------------------------------------------------------------------------")

#### SECTION 2 ####
#2.1: Move into the directory where the file is, grab the path for later
os.chdir(rstDir)
path = os.getcwd()

#2.2: Load the solution from the rst file into "mysol"
mysol = post.load_solution(rstFile)

#2.3: Load the mesh from the solution into "mymesh"
mymesh = mysol.mesh

#2.4: Frab the stresses from first solution step, then get equivilent stress
print ("++ Getting result information from file")
str1 = mysol.stress(set=1)
rstval = str1.von_mises.result_fields_container

#2.5: Make a copy of the mesh (we don't need a copy now, but we will in the next version of this script)
theMesh = mymesh.deep_copy()

#plot it to check it
#   Note: to move on type q or close the window

#### SECTION 3 ####
#3.1: create a Pyansys plotter object first
print ("++ Making plot")
plt = DpfPlotter()

#3.2: Add the mesh and the results you pulled into the plot
plt.add_field(rstval[0],theMesh,show_edges=False)

#3.3: show the plot. There are a ton of options, for now use the basics. 
plt.show_figure(
    show_axes=True,
    parallel_projection=False,
    background="#aaaaaa"
)

#### SECTION 4 ####

print ("++ Making output file")

#4.1: Create a VTK operator for exporting to VTK
vtkop = coreops.serialization.vtk_export() 

#4.2: Add the mesh to the operator
vtkop.inputs.mesh.connect(theMesh)

#4.3: Specify the output file name
vtkop.inputs.file_path.connect(outfname)

#4.4: Attach the results to the operatior
vtkop.inputs.fields1.connect(rstval)

#4.5: Run the operator, which creates the VTK file. 
#     Print the message created by the operator, just in case you got an error
runMsg = vtkop.run()
print("Message from Output Operation: ", runMsg)

#4.6: Close out
print ("---------------------------------------------------------------------------")
print ("Done")




